"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var spies = require("chai-spies");
var lodash = require("lodash");
var Lazy = require("lazy.js");
var functions_1 = require("../functions");
var stream_1 = require("../stream");
var Benchmark = require("benchmark");
chai_1.use(spies);
var numberOfOps = 10;
var itemSource = function () { return stream_1.default.iterate(1, function (i) { return i + 1; }).limit(numberOfOps).toArray(); };
var timerResult = function (start, end) {
    console.log(start);
    console.log(end);
    var diff = end - start;
    var perSecond = 1000 / diff;
    return perSecond * numberOfOps;
};
describe('Benchmark', function () {
    it('map', function () {
        var suite = new Benchmark.Suite;
        var items = itemSource();
        suite.add('lodash', function () { return lodash.each(lodash.map(items, functions_1.Function.identity()), functions_1.Consumer.sink()); })
            .add('java8script', function () { return stream_1.default.of(items).map(functions_1.Function.identity()).forEach(functions_1.Consumer.sink()); })
            .add('lazy', function () { return Lazy(items).map(functions_1.Function.identity()).each(functions_1.Consumer.sink()); })
            .on('cycle', function (event) {
            console.log(event.target.name + " " + event.target.hz);
        })
            .run();
    });
    it('map->filter->first', function () {
        var suite = new Benchmark.Suite;
        var items = itemSource();
        suite.add('lodash', function () { return lodash.first(lodash.filter(lodash.map(items, functions_1.Function.identity()), function (i) { return i < 5; })); })
            .add('java8script', function () { return stream_1.default.of(items).map(functions_1.Function.identity()).filter(function (i) { return i < 5; }).findFirst(); })
            .add('lazy', function () { return Lazy(items).map(functions_1.Function.identity()).filter(function (i) { return i < 5; }).first(); })
            .on('cycle', function (event) {
            console.log(event.target.name + " " + event.target.hz);
        })
            .run();
    });
});
