import Optional from "../optional";
/**
 * A state object for collecting statistics such as count, min, max, sum, and average.
 */
export declare class NumberSummaryStatistics {
    private average;
    private count;
    private max;
    private min;
    private sum;
    constructor();
    /**
     * creates a new, empty NumberSummaryStatisitcs.
     */
    static create(): NumberSummaryStatistics;
    /**
     * Records a new value into the summary information
     * @param n - number to record
     */
    accept(n: number): void;
    /**
     * Combines the state of another NumberSummaryStatistics into this one
     * @param other - other NumberSummaryStatistic to combine with
     */
    combine(other: NumberSummaryStatistics): void;
    /**
     * Returns the arithmetic mean of values recorded, or zero if no values have been recorded.
     */
    getAverage(): number;
    /**
     * Returns the minimum value recorded, or Number.MAX_VALUE if no values have been recorded.
     */
    getMin(): number;
    /**
     * Returns the maximum value recorded, or -Number.MAX_VALUE if no values have been recorded.
     */
    getMax(): number;
    /**
     * Returns the count of values recorded.
     */
    getCount(): number;
    /**
     * Returns the sum of values recorded, or zero if no values have been recorded.
     */
    getSum(): number;
}
export declare class MutableString {
    private value;
    private constructor();
    static empty(): MutableString;
    static of(value: string): MutableString;
    append(postfix: string): void;
    prepend(prefix: string): void;
    concat(other: MutableString): MutableString;
    getValue(): string;
}
export declare class MutableNumber {
    private inputs;
    private total;
    private constructor();
    static empty(): MutableNumber;
    add(value: number): void;
    addTogether(other: MutableNumber): MutableNumber;
    getInputs(): number[];
    getTotal(): number;
    getInputCount(): number;
}
export declare class Holder<T> {
    item?: T;
    constructor(item?: T);
    get(): Optional<T>;
    set(item: T): void;
}
