"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var optional_1 = require("../optional");
/**
 * A state object for collecting statistics such as count, min, max, sum, and average.
 */
var NumberSummaryStatistics = /** @class */ (function () {
    function NumberSummaryStatistics() {
        this.average = 0;
        this.max = -Number.MAX_VALUE;
        this.min = Number.MAX_VALUE;
        this.count = 0;
        this.sum = 0;
    }
    /**
     * creates a new, empty NumberSummaryStatisitcs.
     */
    NumberSummaryStatistics.create = function () {
        return new NumberSummaryStatistics();
    };
    /**
     * Records a new value into the summary information
     * @param n - number to record
     */
    NumberSummaryStatistics.prototype.accept = function (n) {
        this.sum = this.sum + n;
        this.count++;
        this.average = this.sum / this.count;
        this.max = n > this.max ? n : this.max;
        this.min = n < this.min ? n : this.min;
    };
    /**
     * Combines the state of another NumberSummaryStatistics into this one
     * @param other - other NumberSummaryStatistic to combine with
     */
    NumberSummaryStatistics.prototype.combine = function (other) {
        this.sum = this.sum + other.getSum();
        this.count = this.count + other.count;
        this.average = this.sum / this.count;
        this.min = this.min < other.getMin() ? this.min : other.getMin();
        this.max = this.max > other.getMax() ? this.max : other.getMax();
    };
    /**
     * Returns the arithmetic mean of values recorded, or zero if no values have been recorded.
     */
    NumberSummaryStatistics.prototype.getAverage = function () {
        return this.average;
    };
    /**
     * Returns the minimum value recorded, or Number.MAX_VALUE if no values have been recorded.
     */
    NumberSummaryStatistics.prototype.getMin = function () {
        return this.min;
    };
    /**
     * Returns the maximum value recorded, or -Number.MAX_VALUE if no values have been recorded.
     */
    NumberSummaryStatistics.prototype.getMax = function () {
        return this.max;
    };
    /**
     * Returns the count of values recorded.
     */
    NumberSummaryStatistics.prototype.getCount = function () {
        return this.count;
    };
    /**
     * Returns the sum of values recorded, or zero if no values have been recorded.
     */
    NumberSummaryStatistics.prototype.getSum = function () {
        return this.sum;
    };
    return NumberSummaryStatistics;
}());
exports.NumberSummaryStatistics = NumberSummaryStatistics;
var MutableString = /** @class */ (function () {
    function MutableString(value) {
        this.value = value;
    }
    MutableString.empty = function () {
        return new MutableString("");
    };
    MutableString.of = function (value) {
        return new MutableString(value);
    };
    MutableString.prototype.append = function (postfix) {
        this.value = this.value + postfix;
    };
    MutableString.prototype.prepend = function (prefix) {
        this.value = prefix + this.value;
    };
    MutableString.prototype.concat = function (other) {
        this.append(other.getValue());
        return this;
    };
    MutableString.prototype.getValue = function () {
        return this.value;
    };
    return MutableString;
}());
exports.MutableString = MutableString;
var MutableNumber = /** @class */ (function () {
    function MutableNumber(inputs, total) {
        this.inputs = inputs;
        this.total = total;
    }
    MutableNumber.empty = function () {
        return new MutableNumber([], 0);
    };
    MutableNumber.prototype.add = function (value) {
        this.total = this.total + value;
        this.inputs.push(value);
    };
    MutableNumber.prototype.addTogether = function (other) {
        var newInputs = this.inputs.concat(other.getInputs());
        var newTotal = this.total + this.getTotal();
        return new MutableNumber(newInputs, newTotal);
    };
    MutableNumber.prototype.getInputs = function () {
        return this.inputs.slice();
    };
    MutableNumber.prototype.getTotal = function () {
        return this.total;
    };
    MutableNumber.prototype.getInputCount = function () {
        return this.inputs.length;
    };
    return MutableNumber;
}());
exports.MutableNumber = MutableNumber;
var Holder = /** @class */ (function () {
    function Holder(item) {
        this.item = item;
    }
    Holder.prototype.get = function () {
        return optional_1.default.ofNullable(this.item);
    };
    Holder.prototype.set = function (item) {
        this.item = item;
    };
    return Holder;
}());
exports.Holder = Holder;
