import Stream from '../stream';
import { BiPredicate, BiConsumer, BiFunction } from '../functions';
import Optional from '../optional';
/**
 * key value mapping interface
 * null or undefined keys are not allowed and should throw an error
 */
export interface Map<K, V> {
    clear(): void;
    get(key: K): V | null;
    getOrDefault(key: K, defaultVal: V): V;
    getOptional(key: K): Optional<V>;
    put(key: K, value: V): V | null;
    putIfAbsent(key: K, value: V): V | null;
    putAll(map: Map<K, V>): void;
    containsKey(key: K): boolean;
    containsValue(value: V, equalityTest?: BiPredicate<V, V>): boolean;
    keySet(): K[];
    values(): V[];
    entrySet(): Entry<K, V>[];
    keyStream(): Stream<K>;
    valueStream(): Stream<V>;
    entryStream(): Stream<Entry<K, V>>;
    forEach(consumer: BiConsumer<K, V>): void;
    isEmpty(): boolean;
    remove(key: K): V | null;
    merge(key: K, value: V, remappingFunction: BiFunction<V>): V | null;
}
export declare const Map: {
    empty<K, V>(): Map<K, V>;
    of<K, V>(k1?: K | undefined, v1?: V | undefined, k2?: K | undefined, v2?: V | undefined, k3?: K | undefined, v3?: V | undefined, k4?: K | undefined, v4?: V | undefined, k5?: K | undefined, v5?: V | undefined): Map<K, V>;
};
export interface Entry<K, V> {
    readonly key: K;
    readonly value: V;
    getValue(): V;
    getKey(): K;
}
export declare const Entry: {
    of<K, V>(key: K, value: V): Entry<K, V>;
};
