"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var stream_1 = require("../stream");
var chai_1 = require("chai");
var spies = require("chai-spies");
chai_1.use(spies);
describe('Stream as StreamIterator', function () {
    describe('hasNext', function () {
        it('it should return true if an element exists in the iterator', function () {
            var stream = stream_1.default.ofValue(1);
            var streamIterator = stream.streamIterator();
            chai_1.expect(streamIterator.hasNext()).to.be.true;
        });
        it('it should return false if an element doesnt exists in the iterator', function () {
            var stream = stream_1.default.empty();
            var streamIterator = stream.streamIterator();
            chai_1.expect(streamIterator.hasNext()).to.be.false;
        });
        it('it should return false if an element doesnt exists in the iterator, after using up', function () {
            var stream = stream_1.default.ofValues(1);
            var streamIterator = stream.streamIterator();
            chai_1.expect(streamIterator.hasNext()).to.be.true;
            streamIterator.getNext();
            chai_1.expect(streamIterator.hasNext()).to.be.false;
        });
    });
    describe('getNext', function () {
        it('it should return a value laden optional if value exists', function () {
            var value = 1;
            var stream = stream_1.default.ofValue(value);
            var streamIterator = stream.streamIterator();
            var result = streamIterator.getNext();
            chai_1.expect(result.isPresent()).to.be.true;
            chai_1.expect(result.get()).to.be.eq(value);
        });
        it('it should return a value empty optional if value exists', function () {
            var stream = stream_1.default.empty();
            var streamIterator = stream.streamIterator();
            var result = streamIterator.getNext();
            chai_1.expect(result.isPresent()).to.be.false;
        });
        it('it should return a value empty optional if hasNext is false', function () {
            var stream = stream_1.default.empty();
            var streamIterator = stream.streamIterator();
            chai_1.expect(streamIterator.hasNext()).to.be.false;
            var result = streamIterator.getNext();
            chai_1.expect(streamIterator);
            chai_1.expect(result.isPresent()).to.be.false;
        });
        it('it should return a value laden optional if hasNext is true', function () {
            var value = 1;
            var stream = stream_1.default.ofValue(value);
            var streamIterator = stream.streamIterator();
            chai_1.expect(streamIterator.hasNext()).to.be.true;
            var result = streamIterator.getNext();
            chai_1.expect(result.isPresent()).to.be.true;
            chai_1.expect(result.get()).to.be.eq(value);
        });
    });
    describe('tryAdvance', function () {
        it('it should return true and consume value if value exists', function () {
            var value = 1;
            var stream = stream_1.default.ofValue(value);
            var streamIterator = stream.streamIterator();
            var consumerSpy = chai_1.spy(function (value) { return value + value; });
            var result = streamIterator.tryAdvance(consumerSpy);
            chai_1.expect(result).to.be.true;
            chai_1.expect(consumerSpy).to.have.been.called.with(value);
        });
        it('it should return true and consume value if value exists', function () {
            var stream = stream_1.default.empty();
            var streamIterator = stream.streamIterator();
            var consumerSpy = chai_1.spy(function (value) { return value + value; });
            var result = streamIterator.tryAdvance(consumerSpy);
            chai_1.expect(result).to.be.false;
            chai_1.expect(consumerSpy).to.not.have.been.called;
        });
    });
});
